==> react-button-share-1.7.0.tgz: package/lib/index.js <==
import PropTypes from 'prop-types';
import React from 'react';
import cx from 'classnames';
import Socialtwitter from '@schibstedspain/sui-svgiconset/lib/Socialtwitter';
import Socialfacebook from '@schibstedspain/sui-svgiconset/lib/Socialfacebook';
import Commentsquare from '@schibstedspain/sui-svgiconset/lib/Commentsquare';
import Envelopeclosed from '@schibstedspain/sui-svgiconset/lib/Envelopeclosed';

var getOnClickHandle = function getOnClickHandle(src) {
  return function () {
    return window.open(src);
  };
};

var parseHttpSchemeOfUrl = function parseHttpSchemeOfUrl(urlToEval) {
  return !urlToEval.indexOf('http') || !urlToEval.indexOf('https') ? urlToEval : "http://" + urlToEval;
};

var getShareDefinition = function getShareDefinition(url, shareText, type) {
  var parsedShareUrl = url && parseHttpSchemeOfUrl(url);

  switch (type) {
    case 'facebook':
      return {
        src: "https://www.facebook.com/share.php?u=" + parsedShareUrl + "?opi=140&quote=" + shareText + "&tti=1&pagination=1&RowGrid=2",
        icon: Socialfacebook
      };

    case 'twitter':
      return {
        src: "http://twitter.com/share?url=" + parsedShareUrl + "&tti=1&pagination=1&RowGrid=2&text=" + shareText,
        icon: Socialtwitter
      };

    case 'whatsapp':
      return {
        src: "whatsapp://send?text=" + shareText + " - " + parsedShareUrl,
        icon: Commentsquare
      };

    case 'email':
      return {
        src: "mailto:?&body=" + shareText + " - " + parsedShareUrl,
        icon: Envelopeclosed
      };

    default:
      return {};
  }
};

var ButtonShare = function ButtonShare(_ref) {
  var type = _ref.type,
      icon = _ref.icon,
      onClick = _ref.onClick,
      _ref$shareText = _ref.shareText,
      shareText = _ref$shareText === void 0 ? '' : _ref$shareText,
      url = _ref.url;
  var shareDefinition = getShareDefinition(url, shareText, type);
  var Icon = icon || shareDefinition.icon;
  return React.createElement("button", {
    className: cx('sui-ButtonShare', "sui-ButtonShare--" + type),
    onClick: !onClick ? getOnClickHandle(shareDefinition.src) : onClick
  }, React.createElement(Icon, {
    svgClass: "sui-ButtonShare-svgIcon",
    fillColor: false
  }));
};

ButtonShare.displayName = 'ButtonShare';
export default ButtonShare;

==> react-button-share-1.8.0.tgz: package/lib/index.js <==
import PropTypes from 'prop-types';
import React from 'react';
import cx from 'classnames';
import Socialtwitter from '@s-ui/react-icons/lib/Socialtwitter';
import Socialfacebook from '@s-ui/react-icons/lib/Socialfacebook';
import Commentsquare from '@s-ui/react-icons/lib/Commentsquare';
import Envelopeclosed from '@s-ui/react-icons/lib/Envelopeclosed';

var getOnClickHandle = function getOnClickHandle(src) {
  return function () {
    return window.open(src);
  };
};

var parseHttpSchemeOfUrl = function parseHttpSchemeOfUrl(urlToEval) {
  return !urlToEval.indexOf('http') || !urlToEval.indexOf('https') ? urlToEval : "http://" + urlToEval;
};

var getShareDefinition = function getShareDefinition(url, shareText, type) {
  var parsedShareUrl = url && parseHttpSchemeOfUrl(url);

  switch (type) {
    case 'facebook':
      return {
        src: "https://www.facebook.com/share.php?u=" + parsedShareUrl + "?opi=140&quote=" + shareText + "&tti=1&pagination=1&RowGrid=2",
        icon: Socialfacebook
      };

    case 'twitter':
      return {
        src: "http://twitter.com/share?url=" + parsedShareUrl + "&tti=1&pagination=1&RowGrid=2&text=" + shareText,
        icon: Socialtwitter
      };

    case 'whatsapp':
      return {
        src: "whatsapp://send?text=" + shareText + " - " + parsedShareUrl,
        icon: Commentsquare
      };

    case 'email':
      return {
        src: "mailto:?&body=" + shareText + " - " + parsedShareUrl,
        icon: Envelopeclosed
      };

    default:
      return {};
  }
};

var ButtonShare = function ButtonShare(_ref) {
  var type = _ref.type,
      icon = _ref.icon,
      onClick = _ref.onClick,
      _ref$shareText = _ref.shareText,
      shareText = _ref$shareText === void 0 ? '' : _ref$shareText,
      url = _ref.url;
  var shareDefinition = getShareDefinition(url, shareText, type);
  var Icon = icon || shareDefinition.icon;
  return React.createElement("button", {
    className: cx('sui-ButtonShare', "sui-ButtonShare--" + type),
    onClick: !onClick ? getOnClickHandle(shareDefinition.src) : onClick
  }, React.createElement(Icon, {
    svgClass: "sui-ButtonShare-svgIcon",
    fillColor: false
  }));
};

ButtonShare.displayName = 'ButtonShare';
export default ButtonShare;
